pub struct FidlvizBits(/* private fields */);Implementations
Sourceimpl FidlvizBits
impl FidlvizBits
Sourceimpl FidlvizBits
impl FidlvizBits
Sourcepub const fn empty() -> FidlvizBits
pub const fn empty() -> FidlvizBits
Get a flags value with all bits unset.
Sourcepub const fn all() -> FidlvizBits
pub const fn all() -> FidlvizBits
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<FidlvizBits>
pub const fn from_bits(bits: u8) -> Option<FidlvizBits>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> FidlvizBits
pub const fn from_bits_truncate(bits: u8) -> FidlvizBits
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> FidlvizBits
pub const fn from_bits_retain(bits: u8) -> FidlvizBits
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<FidlvizBits>
pub fn from_name(name: &str) -> Option<FidlvizBits>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: FidlvizBits) -> bool
pub const fn intersects(&self, other: FidlvizBits) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: FidlvizBits) -> bool
pub const fn contains(&self, other: FidlvizBits) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: FidlvizBits)
pub fn insert(&mut self, other: FidlvizBits)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: FidlvizBits)
pub fn remove(&mut self, other: FidlvizBits)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: FidlvizBits)
pub fn toggle(&mut self, other: FidlvizBits)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: FidlvizBits, value: bool)
pub fn set(&mut self, other: FidlvizBits, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: FidlvizBits) -> FidlvizBits
pub const fn intersection(self, other: FidlvizBits) -> FidlvizBits
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: FidlvizBits) -> FidlvizBits
pub const fn union(self, other: FidlvizBits) -> FidlvizBits
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: FidlvizBits) -> FidlvizBits
pub const fn difference(self, other: FidlvizBits) -> FidlvizBits
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: FidlvizBits) -> FidlvizBits
pub const fn symmetric_difference(self, other: FidlvizBits) -> FidlvizBits
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> FidlvizBits
pub const fn complement(self) -> FidlvizBits
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl FidlvizBits
impl FidlvizBits
Sourcepub const fn iter(&self) -> Iter<FidlvizBits> ⓘ
pub const fn iter(&self) -> Iter<FidlvizBits> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<FidlvizBits> ⓘ
pub const fn iter_names(&self) -> IterNames<FidlvizBits> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.