pub struct GoldenBits(/* private fields */);Implementations
Sourceimpl GoldenBits
impl GoldenBits
pub const A: GoldenBits
Sourceimpl GoldenBits
impl GoldenBits
Sourcepub const fn empty() -> GoldenBits
pub const fn empty() -> GoldenBits
Get a flags value with all bits unset.
Sourcepub const fn all() -> GoldenBits
pub const fn all() -> GoldenBits
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<GoldenBits>
pub const fn from_bits(bits: u16) -> Option<GoldenBits>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> GoldenBits
pub const fn from_bits_truncate(bits: u16) -> GoldenBits
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> GoldenBits
pub const fn from_bits_retain(bits: u16) -> GoldenBits
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<GoldenBits>
pub fn from_name(name: &str) -> Option<GoldenBits>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: GoldenBits) -> bool
pub const fn intersects(&self, other: GoldenBits) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: GoldenBits) -> bool
pub const fn contains(&self, other: GoldenBits) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: GoldenBits)
pub fn insert(&mut self, other: GoldenBits)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: GoldenBits)
pub fn remove(&mut self, other: GoldenBits)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: GoldenBits)
pub fn toggle(&mut self, other: GoldenBits)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: GoldenBits, value: bool)
pub fn set(&mut self, other: GoldenBits, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: GoldenBits) -> GoldenBits
pub const fn intersection(self, other: GoldenBits) -> GoldenBits
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: GoldenBits) -> GoldenBits
pub const fn union(self, other: GoldenBits) -> GoldenBits
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: GoldenBits) -> GoldenBits
pub const fn difference(self, other: GoldenBits) -> GoldenBits
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: GoldenBits) -> GoldenBits
pub const fn symmetric_difference(self, other: GoldenBits) -> GoldenBits
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> GoldenBits
pub const fn complement(self) -> GoldenBits
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl GoldenBits
impl GoldenBits
Sourcepub const fn iter(&self) -> Iter<GoldenBits> ⓘ
pub const fn iter(&self) -> Iter<GoldenBits> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<GoldenBits> ⓘ
pub const fn iter_names(&self) -> IterNames<GoldenBits> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.