pub struct TableWithUnknownEnveloepsAfterKnownEnvelopesStruct {
pub t: TableWithUnknownEnvelopesAfterKnownEnvelopes,
}Fields
t: TableWithUnknownEnvelopesAfterKnownEnvelopesTrait Implementations
Sourceimpl Decode<TableWithUnknownEnveloepsAfterKnownEnvelopesStruct, DefaultFuchsiaResourceDialect> for TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
impl Decode<TableWithUnknownEnveloepsAfterKnownEnvelopesStruct, DefaultFuchsiaResourceDialect> for TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
Sourceimpl Encode<TableWithUnknownEnveloepsAfterKnownEnvelopesStruct, DefaultFuchsiaResourceDialect> for &mut TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
impl Encode<TableWithUnknownEnveloepsAfterKnownEnvelopesStruct, DefaultFuchsiaResourceDialect> for &mut TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
Sourceimpl<T0: Encode<TableWithUnknownEnvelopesAfterKnownEnvelopes, DefaultFuchsiaResourceDialect>> Encode<TableWithUnknownEnveloepsAfterKnownEnvelopesStruct, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<TableWithUnknownEnvelopesAfterKnownEnvelopes, DefaultFuchsiaResourceDialect>> Encode<TableWithUnknownEnveloepsAfterKnownEnvelopesStruct, DefaultFuchsiaResourceDialect> for (T0,)
Sourceimpl PartialEq for TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
impl PartialEq for TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
Sourcefn eq(&self, other: &TableWithUnknownEnveloepsAfterKnownEnvelopesStruct) -> bool
fn eq(&self, other: &TableWithUnknownEnveloepsAfterKnownEnvelopesStruct) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ResourceTypeMarker for TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
impl ResourceTypeMarker for TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
Sourcetype Borrowed<'a> = &'a mut TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
type Borrowed<'a> = &'a mut TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
impl StructuralPartialEq for TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
Sourceimpl TypeMarker for TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
impl TypeMarker for TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
Sourcetype Owned = TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
type Owned = TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
impl RefUnwindSafe for TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
impl Send for TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
impl Sync for TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
impl Unpin for TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
impl UnsafeUnpin for TableWithUnknownEnveloepsAfterKnownEnvelopesStruct
impl UnwindSafe for TableWithUnknownEnveloepsAfterKnownEnvelopesStruct