pub struct VectorOfUint64 {
pub v: Vec<u64>,
}Fields
v: Vec<u64>Trait Implementations
Sourceimpl Clone for VectorOfUint64
impl Clone for VectorOfUint64
Sourcefn clone(&self) -> VectorOfUint64
fn clone(&self) -> VectorOfUint64
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VectorOfUint64
impl Debug for VectorOfUint64
Sourceimpl<D> Decode<VectorOfUint64, D> for VectorOfUint64where
D: ResourceDialect,
impl<D> Decode<VectorOfUint64, D> for VectorOfUint64where
D: ResourceDialect,
Sourcefn new_empty() -> VectorOfUint64
fn new_empty() -> VectorOfUint64
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<VectorOfUint64, D> for &VectorOfUint64where
D: ResourceDialect,
impl<D> Encode<VectorOfUint64, D> for &VectorOfUint64where
D: ResourceDialect,
impl Eq for VectorOfUint64
Sourceimpl Hash for VectorOfUint64
impl Hash for VectorOfUint64
Sourceimpl Ord for VectorOfUint64
impl Ord for VectorOfUint64
Sourcefn cmp(&self, other: &VectorOfUint64) -> Ordering
fn cmp(&self, other: &VectorOfUint64) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for VectorOfUint64
impl PartialEq for VectorOfUint64
Sourcefn eq(&self, other: &VectorOfUint64) -> bool
fn eq(&self, other: &VectorOfUint64) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for VectorOfUint64
impl PartialOrd for VectorOfUint64
impl Persistable for VectorOfUint64
impl StructuralPartialEq for VectorOfUint64
Sourceimpl TypeMarker for VectorOfUint64
impl TypeMarker for VectorOfUint64
Sourcetype Owned = VectorOfUint64
type Owned = VectorOfUint64
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for VectorOfUint64
impl ValueTypeMarker for VectorOfUint64
Sourcetype Borrowed<'a> = &'a VectorOfUint64
type Borrowed<'a> = &'a VectorOfUint64
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<VectorOfUint64 as TypeMarker>::Owned,
) -> <VectorOfUint64 as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<VectorOfUint64 as TypeMarker>::Owned, ) -> <VectorOfUint64 as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for VectorOfUint64
impl RefUnwindSafe for VectorOfUint64
impl Send for VectorOfUint64
impl Sync for VectorOfUint64
impl Unpin for VectorOfUint64
impl UnsafeUnpin for VectorOfUint64
impl UnwindSafe for VectorOfUint64